==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/ru/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Пользователь отменил запрос элемента на веб-сайте',
    'a_user_requested' => 'Пользователь запросил элемент на веб-сайте',
    'accessory_name' => 'Аксессуар:',
    'additional_notes' => 'Дополнительные Примечания:',
    'admin_has_created' => 'Администратор создал аккаунт для вас на :web.',
    'asset' => 'Актив:',
    'asset_name' => 'Имя актива:',
    'asset_requested' => 'Актив запрошен',
    'asset_tag' => 'Инвентарный номер актива:',
    'assigned_to' => 'Выдано',
    'best_regards' => 'С наилучшими пожеланиями,',
    'canceled' => 'Отменен:',
    'checkin_date' => 'Дата возврата:',
    'checkout_date' => 'Дата выдачи:',
    'click_to_confirm' => 'Пожалуйста, перейдите по ссылке, чтобы подтвердить ваш :web аккаунт:',
    'click_on_the_link_accessory' => 'Пожалуйста, перейдите по ссылке внизу, чтобы подтвердить получение аксессуара.',
    'click_on_the_link_asset' => 'Пожалуйста, перейдите по ссылке внизу, чтобы подтвердить получение актива.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Текущее количество',
    'Days' => 'Дни',
    'days' => 'Дни',
    'expecting_checkin_date' => 'Ожидаемая дата возврата:',
    'expires' => 'Истекает',
    'Expiring_Assets_Report' => 'Отчет об истечении активов.',
    'Expiring_Licenses_Report' => 'Отчет об истечении лицензий.',
    'hello' => 'Привет',
    'hi' => 'Привет',
    'i_have_read' => 'Я прочитал и согласен с условиями использования, и получил этот предмет.',
    'item' => 'Предмет:',
    'Item_Request_Canceled' => 'Запрос предмета отменен',
    'Item_Requested' => 'Предмет запрошен',
    'link_to_update_password' => 'Пожалуйста, перейдите по ссылке, чтобы обновить ваш :web пароль:',
    'login_first_admin' => 'Чтобы войти в Snipe-It используйте следующие логин и пароль:',
    'login' => 'Логин:',
    'Low_Inventory_Report' => 'Отчет о заканчивающихся предметах',
    'min_QTY' => 'Мин Кол-во',
    'name' => 'Название',
    'new_item_checked' => 'Новый предмет был выдан под вашем именем, подробности ниже.',
    'password' => 'Пароль:',
    'password_reset' => 'Сброс пароля',

    'read_the_terms' => 'Пожалуйста, прочитайте условия использования ниже.',
    'read_the_terms_and_click' => 'Пожалуйста, прочитайте условия использования ниже и нажмите на ссылку внизу, чтобы подтвердить, что вы ознакомились и соглашаетесь с условиями использования и получили актив.',
    'requested' => 'Запрошено:',
    'reset_link' => 'Ваша ссылка на сброс пароля',
    'reset_password' => 'Нажмите здесь, чтобы сбросить свой пароль:',
    'serial' => 'Серийный номер',
    'supplier' => 'Поставщик',
    'tag' => 'Метка',
    'test_email' => 'Тестовое сообщение от Snipe-IT',
    'test_mail_text' => 'Это тестовое сообщение от Snipe-IT. Если вы его получили, значит почта работает :)',
    'the_following_item' => 'Данный предмет был возвращен: ',
    'low_inventory_alert' => 'Осталась :count штука, что или уже ниже минимального запаса, или скоро будет ниже.|Осталось :count штук, что или уже ниже минимального запаса, или скоро будет ниже.',
    'assets_warrantee_alert' => 'Имеется :count актив, гарантия на который истечет в следующ(ие/ий) :threshold дней/день.|Имеется :count активов, гарантия на которые истечет в следующ(ие/ий) :threshold дней/день.',
    'license_expiring_alert' => 'Имеется :count лицензия, срок которой истечет в следующ(ие/ий) :threshold дней/день.|Имеются :count лицензии, срок которых истечет в следующ(ие/ий) :threshold дней/день.',
    'to_reset' => 'Чтобы сбросить ваш :web пароль, заполните форму:',
    'type' => 'Тип',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Пользователь',
    'username' => 'Имя пользователя',
    'welcome' => 'Добро пожаловать, :name',
    'welcome_to' => 'Добро пожаловать на :web!',
    'your_credentials' => 'Ваш логин и пароль от Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'Посмотреть активы'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/ru/mail.php <==
<?php

return [
    'a_user_canceled' => 'Пользователь отменил запрос элемента на веб-сайте',
    'a_user_requested' => 'Пользователь запросил элемент на веб-сайте',
    'accessory_name' => 'Аксессуар:',
    'additional_notes' => 'Дополнительные Примечания:',
    'admin_has_created' => 'Администратор создал аккаунт для вас на :web.',
    'asset' => 'Актив:',
    'asset_name' => 'Имя актива:',
    'asset_requested' => 'Актив запрошен',
    'asset_tag' => 'Тег актива',
    'assigned_to' => 'Выдано',
    'best_regards' => 'С наилучшими пожеланиями,',
    'canceled' => 'Отменен:',
    'checkin_date' => 'Дата возврата:',
    'checkout_date' => 'Дата выдачи:',
    'click_to_confirm' => 'Пожалуйста, перейдите по ссылке, чтобы подтвердить ваш :web аккаунт:',
    'click_on_the_link_accessory' => 'Пожалуйста, перейдите по ссылке внизу, чтобы подтвердить получение аксессуара.',
    'click_on_the_link_asset' => 'Пожалуйста, перейдите по ссылке внизу, чтобы подтвердить получение актива.',
    'Confirm_Asset_Checkin' => 'Подтверждение возврата активов',
    'Confirm_Accessory_Checkin' => 'Подтвердить возврат аксессуара',
    'Confirm_accessory_delivery' => 'Подтвердить доставку аксессуара',
    'Confirm_license_delivery' => 'Подтвердите получение лицензии',
    'Confirm_asset_delivery' => 'Подтвердить доставку актива',
    'Confirm_consumable_delivery' => 'Подтвердить доставку расходников',
    'current_QTY' => 'Текущее количество',
    'Days' => 'Дни',
    'days' => 'Дни',
    'expecting_checkin_date' => 'Ожидаемая дата возврата:',
    'expires' => 'Истекает',
    'Expiring_Assets_Report' => 'Отчет об истечении активов.',
    'Expiring_Licenses_Report' => 'Отчет об истечении лицензий.',
    'hello' => 'Привет',
    'hi' => 'Привет',
    'i_have_read' => 'Я прочитал и согласен с условиями использования, и получил этот предмет.',
    'item' => 'Предмет:',
    'Item_Request_Canceled' => 'Запрос предмета отменен',
    'Item_Requested' => 'Предмет запрошен',
    'link_to_update_password' => 'Пожалуйста, перейдите по ссылке, чтобы обновить ваш :web пароль:',
    'login_first_admin' => 'Чтобы войти в Snipe-It используйте следующие логин и пароль:',
    'login' => 'Логин:',
    'Low_Inventory_Report' => 'Отчет о заканчивающихся предметах',
    'min_QTY' => 'Мин Кол-во',
    'name' => 'Название',
    'new_item_checked' => 'Новый предмет был выдан под вашем именем, подробности ниже.',
    'password' => 'Пароль:',
    'password_reset' => 'Сброс пароля',

    'read_the_terms' => 'Пожалуйста, прочитайте условия использования ниже.',
    'read_the_terms_and_click' => 'Пожалуйста, прочитайте условия использования ниже и нажмите на ссылку внизу, чтобы подтвердить, что вы ознакомились и соглашаетесь с условиями использования и получили актив.',
    'requested' => 'Запрошено:',
    'reset_link' => 'Ваша ссылка на сброс пароля',
    'reset_password' => 'Нажмите здесь, чтобы сбросить свой пароль:',
    'serial' => 'Серийный номер',
    'supplier' => 'Поставщик',
    'tag' => 'Метка',
    'test_email' => 'Тестовое сообщение от Snipe-IT',
    'test_mail_text' => 'Это тестовое сообщение от Snipe-IT. Если вы его получили, значит почта работает :)',
    'the_following_item' => 'Данный предмет был возвращен: ',
    'low_inventory_alert' => 'Осталась :count штука, что или уже ниже минимального запаса, или скоро будет ниже.|Осталось :count штук, что или уже ниже минимального запаса, или скоро будет ниже.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'Имеется :count лицензия, срок которой истечет в следующ(ие/ий) :threshold дней/день.|Имеются :count лицензии, срок которых истечет в следующ(ие/ий) :threshold дней/день.',
    'to_reset' => 'Чтобы сбросить ваш :web пароль, заполните форму:',
    'type' => 'Тип',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Пользователь',
    'username' => 'Имя пользователя',
    'welcome' => 'Добро пожаловать, :name',
    'welcome_to' => 'Добро пожаловать на :web!',
    'your_credentials' => 'Ваш логин и пароль от Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Напоминание: приближается крайний срок проверки :name',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'Посмотреть активы',
];
